<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Kaikki tiedostot (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Yhdistetty</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistetään</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Osoitteen haku</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Todennus</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Katkaistu</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Lentotila</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Lopeta langaton tietoliikenne</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Lentotilan käyttöönotto sammuttaa langattoman verkon, jaetun tukiaseman ja Bluetoothin</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Sovelluksen välityspalvelin</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Määritä välityspalvelimia</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Välityspalvelimen tyyppi</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP osoite</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Virheellinen portti</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valinnainen</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Tarkista &quot;käytä välityspalvelinta&quot; sovelluksessa. Löytyy pikavalikosta määritysten jälkeen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Määritä modeemi ja puhelinverkkoyhteys</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Katkaise</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Lisää PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Haluatko varmasti poistaa tämän määrityksen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>Verkon %1 ominaisuudet</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Verkkon tiedot</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Näytä kaikki verkkoasetukset</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Tiedot kopioitu</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Valitse kaikki</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Verkon tunnistus</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Mitään</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Autom</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ei sido</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Oma tukiasema</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Jaa verkko</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Tukiasema</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Muokkaa tukiasemaa</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nimi (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Turvallisuus</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Taajuusalue</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Jakoasetukset</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Tukiaseman jeattu laite</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Jos haluat käyttää tukiasemana, poista ensin lentotila käytöstä ja ota sitten langaton verkko käyttöön.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Jos haluat käyttää tukiasemana, poista ensin &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Lentotila käytöstä&lt;/a&gt; ja ota sitten langaton verkko käyttöön.</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation>Ota ensin &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Langaton&lt;/a&gt; käyttöön, jos haluat käyttää tukiasemana.</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Haluatko varmasti poistaa tämän määrityksen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>Verkon %1 ominaisuudet</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Määritä välityspalvelimia</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Välityspalvelimen tyyppi</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Autom</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Määrityksen url-osoite</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP välityspalvelin</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS välityspalvelin</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP välityspalvelin</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS välityspalvelin</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ohita yllä mainittujen isäntien ja toimialueiden välityspalvelin määritykset</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Yhdistä, lisää, tuo</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Katkaise</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Lisää VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Tuo VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Tuontivirhe</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Tiedostovirhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>VPN tyyppi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Haluatko varmasti poistaa tämän määrityksen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation>Verkon %1 ominaisuudet</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Yhdistä, muokkaa verkkoasetuksia</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Kytke verkkokaapeli ensin</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Katkaise</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Lisää verkkoyhteys</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Yhdistä, muokkaa verkkoasetuksia</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Katkaise</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Muut verkot</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Poista lentotila ensin käytöstä, jos haluat yhteyden langattomaan verkkoon</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Poista &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;lentotila&lt;/a&gt; ensin käytöstä, jos haluat yhteyden langattomaan verkkoon</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Poista tukiasema ensin käytöstä, jos haluat yhteyden langattomaan verkkoon</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Poista &lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;tukiasema&lt;/a&gt; ensin käytöstä, jos haluat yhteyden langattomaan verkkoon</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>Minun verkko</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Ei sido</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Laitteen MAC-osoite</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Kloonattu MAC-osoite</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Muokkaa MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Taajuusalue</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Autom</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation>MTU (1280-9000)</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Yleinen</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nimi (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Autom. yhteys</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Pois käytöstä</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Autom</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Menetelmä</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Sovelletaan vastaaviin resursseihin</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP osoite</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Verkkopeite</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Virheellinen verkkomaski</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Päällekkäinen IP-osoite</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Pois käytöstä</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuaalinen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Autom</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Menetelmä</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Sovelletaan vastaaviin resursseihin</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP osoite</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Virheellinen IP-osoite</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Etuliite</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Virheellinen verkkomaski</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Päällekkäinen IP-osoite</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Käytä MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Tilanneellinen MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Hylkää EAP-todennus</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Hylkää PAP-todennus</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Hylkää CHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Hylkää MSCHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Hylkää MSCHAPv2-todennus</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ei BSD-pakkausta</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ei tyhjää tiedon pakkausta</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ei TCP-otsakkeiden pakkausta</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Lähetä PPP echo-paketteja</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Palvelu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Turvallisuus</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneloitu TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Suojattu EAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Mitään</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identiteetti</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Salasanavalinnat</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Tallenna salasana tälle käyttäjälle</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Tallenna salasana kaikille käyttäjille</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Kysy aina</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Avain</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Salausavain</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Todennus</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Jaettu avain</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Avoin järjestelmä</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Salausavain</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonyymi tunnus</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Valmistelu</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Pois käytöstä</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonyymi</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Todennettu</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Molemmat</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC-tiedosto</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-sertifikaatti</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Käyttäjä-sertifikaatti</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP versio</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versio 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versio 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Sisäinen todennus</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Kaikki tiedostot (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Virheellinen yhdyskäytävä</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Yhdyskäytävä</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA-sertifikaatti</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Salli Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tunnistautumistapa</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Salausavain</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-sovellus</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Älykortti</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Jaettu avain</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Käyttäjä-sertifikaatti</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Käytä FSID:tä avaimen salasanana</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sertifikaatit (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Varmenteet salasanalla (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Kiinteä avain</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Salasanavalinnat</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Tallennettu</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Kysy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ei vaadita</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Salausavain</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Määritä avaimen suunta</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Avaimen suunta</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Ulkoinen IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Paikallinen IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT-toimialue</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Pyydä sisäinen IP-osoite</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Pakota UDP-kapselointi</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Käytä IP-pakkausta</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Mukautetut salalauseet käyttöön</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Ryhmän nimi</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Ryhmän salasana</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Käytä hybriditodennusta</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Varmennetiedosto</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Käytä MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Turvallisuus</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Kaikki saatavilla (oletus)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (vähemmän suojattu)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (turvallisin)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Tilanneellinen MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Hylkää EAP-todennus</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Hylkää PAP-todennus</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Hylkää CHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Hylkää MSCHAP-todennus</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Hylkää MSCHAPv2-todennus</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ei BSD-pakkausta</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ei tyhjää tiedon pakkausta</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ei TCP-otsakkeiden pakkausta</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ei protokollakentän pakkausta</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ei osoiteen/ohjauksen pakkausta</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Lähetä PPP echo-paketteja</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec käyttöön</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Ryhmän tunnus</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 algoritmit</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 algoritmit</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN lisäasetukset</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Muokkaa yhdyskäytävän porttia</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Yhdyskäytävän portti</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Mukauta neuvotteluväli</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Neuvotteluväli</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Käytä LZO pakkausta</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Käytä TCP-yhteyttä</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Käytä TAP-laitetta</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Mukauta tunnelin MTU:ta</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Mukauta UDP-fragmentin kokoa</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP-fragmentin koko</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Rajoita tunnelin TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Satunnaista ulkoiset isännät</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Toimialue</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Toimittaja</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (oletus)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Verkkonäyttö</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Salaus</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Suojattu (oletus)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Heikko</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Mitään</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT-liikenne</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T kun saatavilla (oletus)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Aina NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Pois käytöstä</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (oletus)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Edelleen salaus</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Palvelin (oletus)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Paikallinen portti</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Poista käytöstä poistuneiden tunnistus</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>VPN turvallisuus</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Salakirjoitus</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC tunnistus</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN välityspalvelin</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Välityspalvelimen tyyppi</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Palvelimen IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Yritä uudelleen virheen sattuessa</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS todennus</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Kohde täsmää</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Ulkoisen varmenteen tyyppi</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Ohjelma</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Palvelin</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Avaintiedosto</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation>MTU (1280-9000)</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Valinnainen</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Todennus vaaditaan</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Poista ensin &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Lentotila&lt;/a&gt; käytöstä, jos haluat muodostaa yhteyden langattomaan verkkoon</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP ristiriita</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Verkkokaapeli %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Yhdistetään &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; yhdistetty</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; katkaistu</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>Ei voi yhdistää &quot;%1&quot;, tarkista reitittin tai verkkokaapeli.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>Ei voi yhdistää &quot;%1&quot;, pysy lähempänä langatonta reititintä</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Yhteyden muodostaminen &quot;%1&quot; epäonnistui, väärä salasana</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Salasana tarvitaan yhteydelle &quot;%1&quot;</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Ei löytynyt &quot;%1&quot; 802.11 WLAN-verkkoa</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Muodosta yhteys &quot;%1&quot;, todennustiedot asetetaan kirjautumisen jälkeen</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Järjestelmän välityspalvelin</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>VPN ei ole yhdistetty tai yhteyden muodostaminen epäonnistui. &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Mene ohjauspaneeliin&lt;/a&gt; ja tarkista.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Kiinteä verkko</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Yhdistä piilotettuun verkkoon</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Minun verkko</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Muut verkot</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation>Yhteysasetukset</translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation>Lisäasetukset</translation>
    </message>
</context>
</TS>